@@ -17,6 +17,7 @@ from ...common.utils import HdfTools
 from uuid import UUID
 from shutil import copy
 import os
+from copy import deepcopy
 
 
 class ModuleGUI(QtWidgets.QDockWidget):
@@ -153,7 +154,7 @@ class ModuleGUI(QtWidgets.QDockWidget):
                 raise ValueError(f'Must pass a params dict with the following keys:\n'
                                  f'{required_keys}\n'
                                  f'Please see the docs for more information.')
-            d = params
+            d = deepcopy(params)
 
         name = d['item_name']
 
